## $Id: pages.py 17423 2023-05-27 07:36:53Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from waeup.kofa.browser.pages import (
    SessionConfigurationAddFormPage,
    SessionConfigurationManageFormPage,
    ConfigurationContainerManageFormPage,
    DatacenterPage, ExportCSVPage)
from waeup.kofa.browser.reports import ReportsContainerPage
from waeup.kofa.interfaces import IConfigurationContainer
from waeup.aaue.interfaces import (
    ICustomSessionConfiguration,
    ICustomSessionConfigurationAdd)

class CustomConfigurationContainerManageFormPage(
    ConfigurationContainerManageFormPage):

    form_fields = grok.AutoFields(IConfigurationContainer).omit(
        'frontpage_dict')
    form_fields['maintmode_enabled_by'].for_display = True

class CustomSessionConfigurationAddFormPage(SessionConfigurationAddFormPage):
    """Add a session configuration object to configuration container.
    """
    form_fields = grok.AutoFields(ICustomSessionConfigurationAdd)

class CustomSessionConfigurationManageFormPage(
    SessionConfigurationManageFormPage):
    """Manage session configuration object.
    """
    form_fields = grok.AutoFields(ICustomSessionConfiguration)

# Temporarily disable data export

class CustomExportCSVPage(ExportCSVPage):

    def update(self):
        if self.request.principal.id not in (
            'admin', 'zope.manager', 'zope.mgr', 'amadin'):
            self.flash('Data export has been temporarily disabled.',
                       type='warning')
            return self.redirect(self.url(self.context))
        return super(CustomExportCSVPage,self).update()

class CustomReportsContainerPage(ReportsContainerPage):

    def update(self):
        if self.request.principal.id not in (
            'admin', 'zope.managers', 'zope.mgrs', 'amadin'):
            self.flash('Reports have been temporarily disabled.',
                       type='warning')
            return self.redirect(self.application_url())
        return super(CustomReportsContainerPage,self).update()
